summaryrefslogtreecommitdiffstats
path: root/src/import/chips/p9/utils/imageProcs/p9_infrastruct_help.H
diff options
context:
space:
mode:
Diffstat (limited to 'src/import/chips/p9/utils/imageProcs/p9_infrastruct_help.H')
-rw-r--r--src/import/chips/p9/utils/imageProcs/p9_infrastruct_help.H4
1 files changed, 3 insertions, 1 deletions
diff --git a/src/import/chips/p9/utils/imageProcs/p9_infrastruct_help.H b/src/import/chips/p9/utils/imageProcs/p9_infrastruct_help.H
index becb4ac7f..bc3784869 100644
--- a/src/import/chips/p9/utils/imageProcs/p9_infrastruct_help.H
+++ b/src/import/chips/p9/utils/imageProcs/p9_infrastruct_help.H
@@ -34,7 +34,9 @@
//
// Various image/ring buffer sizes. Must be used by all users (VBU, FSP, HB, HBI, Cronus)
//
-const uint32_t MAX_SEEPROM_IMAGE_SIZE = 4 * 56 * 1024 - 256; // Max Seeprom size, excl ECC bits (4 banks).
+const uint32_t MAX_SBE_SEEPROM_SIZE = 4 * 64 * 1024; // Max SBE Seeprom size
+const uint32_t MAX_SEEPROM_IMAGE_SIZE = 4 * ((64 * 1024) / 9 * 8) -
+ 256; // Max Seeprom image size, excl ECC bits (4 banks).
const uint32_t MAX_RT_IMAGE_SIZE = 1024 * 1024; // Max Runtime size.
const uint32_t MAX_RING_BUF_SIZE = 60000; // Max ring buffer size.
const uint32_t MAX_OVERRIDES_SIZE = 2 * 1024; // Max overrides section size.
OpenPOWER on IntegriCloud